@@ -20,14 +20,14 @@ class EntryFormModel extends charcoal_DefaultFormModel
 	var $input_panel_8   = '@class:hoge';
 	var $button_panel    = '@style:width:300px;';
 
-	var $first_name      = '@field @input @panel:input_panel_1 @input_type:text @size:40 @caption:Ļ @value:%DTO_VALUE%';
-	var $account         = '@field @input @panel:input_panel_2 @input_type:text @size:20 @caption:  @value:%DTO_VALUE%';
-	var $password        = '@field @input @panel:input_panel_3 @input_type:password @size:20 @caption:ѥ  @value:%DTO_VALUE%';
-	var $sex             = '@field @input @panel:input_panel_4 @input_type:radio @choice_list:sex @checked:1 @caption:   @value:%DTO_VALUE%';
-	var $age             = '@field @input @panel:input_panel_5 @input_type:radio @choice_list:age @checked:2 @caption:ǯ   @value:%DTO_VALUE%';
-	var $area            = '@field @input @panel:input_panel_6 @input_type:select @choice_list:area @caption:ϰ   @value:%DTO_VALUE%';
-	var $favorite        = '@field @input @panel:input_panel_7 @input_type:checkbox @choice_list:favorite @checked:1,4,5 @caption:   @value:%DTO_VALUE%';
-	var $opinion         = '@field @input @panel:input_panel_8 @input_type:textarea @cols:50 @rows:10 @caption:ո   @value:%DTO_VALUE%';
+	var $first_name      = '@field @input @panel:input_panel_1 @input_type:text @size:40 @caption:Ļ';
+	var $account         = '@field @input @panel:input_panel_2 @input_type:text @size:20 @caption: ';
+	var $password        = '@field @input @panel:input_panel_3 @input_type:password @size:20 @caption:ѥ ';
+	var $sex             = '@field @input @panel:input_panel_4 @input_type:radio @choice_list:sex @checked:1 @caption:  ';
+	var $age             = '@field @input @panel:input_panel_5 @input_type:radio @choice_list:age @checked:2 @caption:ǯ  ';
+	var $area            = '@field @input @panel:input_panel_6 @input_type:select @choice_list:area @caption:ϰ  @value:3';
+	var $favorite        = '@field @input @panel:input_panel_7 @input_type:checkbox @choice_list:favorite @checked:1,4,5 @caption:  ';
+	var $opinion         = '@field @input @panel:input_panel_8 @input_type:textarea @cols:50 @rows:10 @caption:ո  ';
 
 	var $submit          = '@input @panel:button_panel @input_type:submit @value:';
 	var $reset           = '@input @panel:button_panel @input_type:reset @value:ꥻå';
